@@ -26,19 +26,12 @@
 #ifndef GNUNET_GTK_H
 #define GNUNET_GTK_H
 
-#ifndef HAVE_USED_CONFIG_H
-#define HAVE_USED_CONFIG_H
-#if HAVE_CONFIG_H
-#include "gnunet_gtk_config.h"
-#endif
-#endif
-
-#include <gnunet/platform.h>
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_fs_service.h>
 #include <gtk/gtk.h>
 #include <gladeui/glade.h>
 #include <gdk/gdkkeysyms.h>
+
 #ifndef GDK_KEY_Return
 #define GDK_KEY_Return GDK_Return
 #endif
@@ -46,6 +39,13 @@
 #define GDK_KEY_Delete GDK_Delete
 #endif
 
+#define _(String) dgettext (PACKAGE, String)
+
+#define DIR_SEPARATOR_STR "/"
+
+#define DIR_SEPARATOR '/'
+
+
 /**
  * Handle for our main loop.
  */
@@ -120,7 +120,7 @@ GNUNET_GTK_get_new_builder2 (const char *filename,
  * @return NULL on error
  */
 #define GNUNET_GTK_get_new_builder(filename, user_data) \
-  GNUNET_GTK_get_new_builder2 (filename, user_data, NULL)
+        GNUNET_GTK_get_new_builder2 (filename, user_data, NULL)
 
 
 /**
