@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2011, 2013 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2011, 2013 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -35,14 +35,14 @@
  * the adjustment
  */
 void
-GNUNET_GTK_setup_expiration_year_adjustment (GtkBuilder * builder)
+GNUNET_GTK_setup_expiration_year_adjustment (GtkBuilder *builder)
 {
   GtkAdjustment *aj;
   unsigned int year;
 
   year = GNUNET_TIME_get_current_year ();
-  aj = GTK_ADJUSTMENT (gtk_builder_get_object
-                       (builder, "expiration_year_adjustment"));
+  aj = GTK_ADJUSTMENT (
+    gtk_builder_get_object (builder, "expiration_year_adjustment"));
   gtk_adjustment_set_value (aj, year + 2);
   gtk_adjustment_set_lower (aj, year + 1);
 }
@@ -56,7 +56,7 @@ GNUNET_GTK_setup_expiration_year_adjustment (GtkBuilder * builder)
  * @return expiration time in the usual GNUnet format
  */
 struct GNUNET_TIME_Absolute
-GNUNET_GTK_get_expiration_time (GtkSpinButton * spin)
+GNUNET_GTK_get_expiration_time (GtkSpinButton *spin)
 {
   struct GNUNET_TIME_Absolute ret;
   int year;
@@ -78,13 +78,14 @@ GNUNET_GTK_get_expiration_time (GtkSpinButton * spin)
  * @return TRUE on success, FALSE on failure
  */
 gboolean
-GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
-                                         gchar * combo_name, guint * p_level)
+GNUNET_GTK_get_selected_anonymity_level (GtkBuilder *builder,
+                                         gchar *combo_name,
+                                         guint *p_level)
 {
   GtkComboBox *combo;
 
   combo = GTK_COMBO_BOX (gtk_builder_get_object (builder, combo_name));
-  if (!combo)
+  if (! combo)
     return FALSE;
   return GNUNET_GTK_get_selected_anonymity_combo_level (combo, p_level);
 }
@@ -98,7 +99,8 @@ GNUNET_GTK_get_selected_anonymity_level (GtkBuilder * builder,
  * @return TRUE on success, FALSE on failure
  */
 gboolean
-GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo, guint *p_level)
+GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo,
+                                               guint *p_level)
 {
   GtkTreeIter iter;
   GtkTreeModel *model;
@@ -107,9 +109,10 @@ GNUNET_GTK_get_selected_anonymity_combo_level (GtkComboBox *combo, guint *p_leve
   if (! gtk_combo_box_get_active_iter (combo, &iter))
     return FALSE;
   model = gtk_combo_box_get_model (combo);
-  if (!model)
+  if (! model)
     return FALSE;
-  gtk_tree_model_get (model, &iter,
+  gtk_tree_model_get (model,
+                      &iter,
                       GNUNET_GTK_ANONYMITY_LEVEL_MC_LEVEL,
                       &level,
                       -1);
